#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Определите переменные среды, соответствующие параметрам
# # сценария jts_upgrade.sh, и их значения по умолчанию
# #
# #===========================================================
# #
# # Этот файл считывается в начале каждого выполнения сценария
# # jts_upgrade.sh. Для каждого допустимого параметра он
# # инициализирует переменную среды предопределенным
# # значением по умолчанию.
# #
# # Пользователям может потребоваться изменить значение по
# # умолчанию, чтобы запускать jts_upgrade.sh со своими
# # значениями, не вводя параметр и его значение вручную
# # в командной строке.
# #
# # ПРЕДУПРЕЖДЕНИЕ:
# # Для некоторых приложений требуется указывать не все
# # переменные.  Внимательно ознакомьтесь с комментарием
# # перед изменением значения.
# #
# #############################################################

# Параметр: -oldJTSHome
# Формат: -oldJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS в предыдущей версии.
# По умолчанию:
# 	<нет>
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#  - Допустим только при обновлении RM и JTS
#
OLD_JTS_HOME=

# Параметр: -jtsContextRoot
# Формат: -jtsContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст JTS
# Значение по умолчанию:
# 	jts
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога
#   (то есть без начальной косой черты)
#
JTS_CONTEXT_ROOT=jts

# Параметр: -lpaContextRoot
# Формат: -lpaContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст LPA
# По умолчанию:
# 	admin
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога (то есть без начальной косой черты)
#
LPA_CONTEXT_ROOT=admin

# Параметр: -oldJTSVersion
# Формат: -oldJTSVersion <версия>
# Описание:
#	 Обновляемая версия JTS.  По умолчанию
# она определяется путем выполнения команды repotools -version для старого экземпляра JTS.
# По умолчанию:
# 	<нет>
# Ограничения:
#  - строка версии должна быть полной
#    например, 3.0.0 или 3.0.1
#
OLD_JTS_VERSION=

# Параметр: -updateTomcatFiles
# Формат: -updateTomcatFiles <yes | no>
# Описание:
# 	Разрешает/запрещает обновление файлов конфигурации Tomcat.
# Значение по умолчанию:
# 	yes
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_TOMCAT_FILES=yes

# Параметр: -oldTomcatHome
# Формат: -oldTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat в предыдущей версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Должен задавать существующий каталог
#
OLD_TOMCAT_HOME=

# Параметр: -newJTSHome
# Формат: -newJTSHome <путь-к-каталогу>
# Описание:
# 	Путь к каталогу конфигурации сервера JTS в новой версии.
# Значение по умолчанию:
# 	conf
# Ограничения:
#  - <путь-к-каталогу> должен указывать на существующий каталог,
#    оканчивающийся на 'server/conf'
NEW_JTS_HOME="$START_DIR/conf"

# Параметр: -newTomcatHome
# Формат: -newTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к домашнему каталогу Tomcat в новой версии.
# Значение по умолчанию:
# 	<нет>
#
NEW_TOMCAT_HOME=

# Параметр: -noPrompt
# Формат: -noPrompt
# Описание:
# 	Не показывать приглашение перед созданием или изменением таблиц
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Параметр: -noVerify
# Формат: -noVerify
# Описание:
# 	Не выполнять проверку файлов teamserver.properties.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Параметр: -overwrite
# Формат: -overwrite
# Описание:
# 	Включает режим замены существующих файлов.
# Значение по умолчанию:
# 	no
# Ограничения:
#  - Допустимо только пустое значение и значение 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Параметр: -noStepPrompt
# Формат: -noStepPrompt
# Описание:
# 	Не выводить запрос перед выполнением шага.
# Значение по умолчанию:
# 	false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
