#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2014. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Определите переменные среды, соответствующие параметрам
# # сценария rm_upgrade.sh, и их значения по умолчанию
# #
# #===========================================================
# #
# # Этот файл считывается в начале каждого выполнения сценария
# # rm_upgrade.sh. Для каждого допустимого параметра он
# # инициализирует переменную среды предопределенным
# # значением по умолчанию.
# #
# # Пользователям может потребоваться изменить значение по
# # умолчанию, чтобы запускать rm_upgrade.sh со своими
# # значениями, не вводя параметр и его значение вручную
# # в командной строке.
# #
# # ПРЕДУПРЕЖДЕНИЕ:
# # Для некоторых приложений требуется указывать не все
# # переменные.  Внимательно ознакомьтесь с комментарием
# # перед изменением значения.
# #
# #############################################################

# Параметр: -oldApplicationHome
# Формат: -oldApplicationHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу приложения в
#  предыдущей версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - это обязательный параметр
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf',
#    например: /Jazz/IBM/RRC_3.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Параметр: -applicationContextRoot
# Формат: -applicationContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст приложения.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога
#   (то есть без начальной косой черты)
#
APPLICATION_CONTEXT_ROOT=

# Параметр: -oldApplicationVersion
# Формат: -oldApplicationVersion <версия>
# Описание:
#	 Обновляемая версия.  По умолчанию она
# определяется командой repotools -version, выполняемой с прежним приложением.
# Значение по умолчанию:
# 	<none>
# Ограничения:
#  - строка версии должна быть полной
#    например, 5.0.0 или 5.0.1
#
OLD_APPLICATION_VERSION=

# Параметр: -updateTomcatFiles
# Формат: -updateTomcatFiles <yes | no>
# Описание:
# 	Разрешает/запрещает обновление файлов конфигурации Tomcat.
# Значение по умолчанию:
# 	yes
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_TOMCAT_FILES=yes

# Параметр: -oldApplicationTomcatHome
# Формат: -oldApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat приложения в предыдущей
#  версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустим только при обновлении RM
#  - Должен задавать существующий каталог
#
OLD_TOMCAT_HOME=

# Параметр: -oldJTSTomcatHome
# Формат: -oldJTSTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat JTS в предыдущей версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустим только при обновлении RM
#  - Должен задавать существующий каталог
#
OLD_JTS_TOMCAT_HOME=

# Параметр: -newApplicationHome
# Формат: -newApplicationHome <путь-к-каталогу>
# Описание:
# 	Путь к домашнему каталогу приложения в новой версии.
# Значение по умолчанию:
# 	conf
# Ограничения:
#  - Допустим только при обновлении RTC, QM и RM
#  - Если допустим, то является обязательным
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf',
#    например: /Jazz/IBM/RRC_4.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Параметр: -newJTSHome
# Формат: -newJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS в новой версии.
# Значение по умолчанию:
# 	Новый домашний каталог приложения
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#
NEW_JTS_HOME=

# Параметр: -newJTSContextRoot
# Формат: -newJTSContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст сервера JTS новой версии.
# Значение по умолчанию:
# 	jts
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога
#   (то есть без начальной косой черты)
#
JTS_CONTEXT_ROOT=jts

# Параметр: -newApplicationTomcatHome
# Формат: -newApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat приложения в новой версии.
# Значение по умолчанию:
# 	<нет>
#
NEW_TOMCAT_HOME=

# Параметр: -newJTSTomcatHome
# Формат: -newJTSTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat JTS в новой версии.
# Значение по умолчанию:
# 	<нет>
#
NEW_JTS_TOMCAT_HOME=

# Параметр: -noPrompt
# Формат: -noPrompt
# Описание:
# 	Не показывать никаких приглашений (всегда использовать noPrompt) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Параметр: -overwrite
# Формат: -overwrite
# Описание:
# 	Принудительная замена (всегда использовать overwrite=yes) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Параметр: -noVerify
# Формат: -noVerify
# Описание:
# 	Не выполнять никаких проверок (всегда использовать noVerify) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Параметр: -noStepPrompt
# Формат: -noStepPrompt
# Описание:
# 	Не выводить запрос перед каждым этапом обновления
# Значение по умолчанию:
# 	false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Параметр: -db.jdbc.location
# Формат: -db.jdbc.location <URL-JDBC>
# Описание:
# 	Расположение JDBC для базы данных RM. (Требуется только при переносе из 4.x в 5.x)
#
#		Примеры:
#			DB2 		//localhost:50000/RM_DB:user=db2admin;password={password};
#			DB2i 		//hostname;hold statements=true;metadata source=1;user=rmDBuser;password={password};
#			ORACLE		thin:rmDBuser/{password}@//oracleserver.example.com:1521/RM_DB
#			SQLSERVER	//localhost:1433;databaseName=RM_DB;user=rmDBuser;password={password};
#			DERBY		conf/rm/derby/repositoryDB
#
#		Примечание:
#			в системах *-nix перед многими символами (такими как |  &  ;  <  >  (  )  $  `  \  "  '  <пробел>  <tab>  <новая-строка>)
#			необходимо вставлять Escape-символ обратная косая черта. 
#		
#			DB2 		//localhost:50000/RM_DB:user=db2admin\;password={password}\;
#			DB2i 		//hostname;hold\ statements=true\;metadata\ source=1\;user=rmDBuser\;password={password}\;
#			ORACLE		thin:rmDBuser/{password}@//oracleserver.example.com:1521/RM_DB
#			SQLSERVER	//localhost:1433\;databaseName=RM_DB\;user=rmDBuser\;password={password}\;
#			DERBY		conf/rm/derby/repositoryDB	
# По умолчанию:
# 	<нет>
# Ограничения:
#  - Принимается только для обновления RM с 4.x
#
DB_JDBC_LOCATION_VALUE=

# Параметр: -db.jdbc.password
# Формат: -db.jdbc.password <пароль-JDBC>
# Описание:
# 	Пароль (простой текст или с шифрованием), который подставляется вместо {password} в URL JDBC.
# По умолчанию:
# 	<нет>
# Ограничения:
#  - Должен быть указан, если в URL JDBC для базы данных RM содержится {password}
#
DB_JDBC_PASSWORD_VALUE=

# Параметр: -db.db2i.schema.name
# Формат: -db.db2i.schema.name <имя-схемы>
# Описание:
# 	Имя схемы базы данных DB2i.
# По умолчанию:
# 	<нет>
# Ограничения:
#  - Должен указываться с помощью типа базы данных DB2i.
#
DB_DB2I_SCHEMA_NAME_VALUE=

# Параметр: -db.db2.dsn.dbname
# Формат: -db.db2.dsn.dbname <имя-базы-данных-DSN>
# Описание:
# 	Имя базы данных DSN DB2Z.
# По умолчанию:
# 	<нет>
# Ограничения:
#  - Должен указываться с помощью типа базы данных DB2z.
#
DB_DB2_DSN_DBNAME_VALUE=

# Параметр: -db.schemaPrefix
# Формат: -db.schemaPrefix <префикс-схемы>
# Описание:
# 	Префикс схемы базы данных.
# По умолчанию:
# 	<нет>
# Ограничения:
#  - Должен указываться с помощью типа базы данных DB2z.
#
DB_SCHEMA_PREFIX_VALUE=

# Параметр: -oldJTSHome
# Формат: -oldJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS в предыдущей версии.
# По умолчанию:
# 	<нет>
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#  - Допустим только при обновлении RM и JTS
#
OLD_JTS_HOME=

# Параметр: -lpaContextRoot
# Формат: -lpaContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст LPA
# По умолчанию:
# 	admin
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога (то есть без начальной косой черты)
#
LPA_CONTEXT_ROOT=admin
